@@ -1,11 +1,19 @@
 package Sah::Schema::hexbuf;
 
-our $DATE = '2018-01-01'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Sah-Schemas-Binary'; # DIST
+our $VERSION = '0.002'; # VERSION
 
 our $schema = [str => {
     summary => 'Binary data encoded in hexdigits',
-    match => qr/\A[0-9A-fa-f]+\z/,
+    match => qr/\A([0-9A-fa-f][0-9A-fa-f])*\z/,
+    examples => [
+        {data=>'', valid=>1},
+        {data=>'f', valid=>0, summary=>'Odd number of digits'},
+        {data=>'fafafa', valid=>1},
+        {data=>'fafafg', valid=>0},
+    ],
 }, {}];
 
 1;
@@ -24,7 +32,7 @@ Sah::Schema::hexbuf - Binary data encoded in hexdigits
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schema::hexbuf (from Perl distribution Sah-Schemas-Binary), released on 2018-01-01.
+This document describes version 0.002 of Sah::Schema::hexbuf (from Perl distribution Sah-Schemas-Binary), released on 2020-03-02.
 
 =head1 HOMEPAGE
 
@@ -48,7 +56,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
